/** options for each client instance */
interface ClientOptions extends RequestInit {
    /** set the common root URL for all API requests */
    baseUrl?: string;
}
interface BaseParams {
    path?: Record<string, unknown>;
    query?: Record<string, unknown>;
}
export declare const methods: readonly ["get", "put", "post", "delete", "options", "head", "patch", "trace"];
export type Method = (typeof methods)[number];
type TruncatedResponse = Omit<Response, 'arrayBuffer' | 'blob' | 'body' | 'clone' | 'formData' | 'json' | 'text'>;
/** Infer request/response from content type */
type UnwrapNonNullable<T> = T extends {
    content: {
        'application/json': any;
    };
} ? T['content']['application/json'] : T extends {
    content: {
        '*/*': any;
    };
} ? T['content']['*/*'] : T;
type Unwrap<T> = T extends NonNullable<T> | undefined ? UnwrapNonNullable<NonNullable<T>> | undefined : UnwrapNonNullable<T>;
export default function createClient<T>(defaultOptions?: ClientOptions): {
    /** Call a GET endpoint */
    get<U extends { [Path in keyof T]: T[Path] extends {
        get: unknown;
    } ? Path : never; }[keyof T], M extends keyof T[U]>(url: U, options: (T[U][M] extends infer T ? T extends T[U][M] ? T extends {
        parameters: any;
    } ? {
        params: T["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U][M] extends infer T_1 ? T_1 extends T[U][M] ? T_1 extends {
        parameters: any;
    } ? {
        params: T_1["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U][M] extends infer T_2 ? T_2 extends T[U][M] ? T_2 extends {
        requestBody: any;
    } ? {
        body: Unwrap<T_2["requestBody"]>;
    } : {
        body?: undefined;
    } : never : never) & Omit<RequestInit, "body">): Promise<{
        data: T[U][keyof T[U]] extends {
            responses: any;
        } ? Unwrap<T[U][keyof T[U]]["responses"] extends infer T_3 ? T_3 extends T[U][keyof T[U]]["responses"] ? T_3 extends {
            200: any;
        } ? T_3[200] : T_3 extends {
            201: any;
        } ? T_3[201] : T_3 extends {
            202: any;
        } ? T_3[202] : T_3 extends {
            default: any;
        } ? T_3["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[U][keyof T[U]] extends {
            responses: any;
        } ? Unwrap<T[U][keyof T[U]]["responses"] extends infer T_4 ? T_4 extends T[U][keyof T[U]]["responses"] ? T_4 extends {
            500: any;
        } ? T_4[500] : T_4 extends {
            404: any;
        } ? T_4[404] : T_4 extends {
            402: any;
        } ? T_4[402] : T_4 extends {
            401: any;
        } ? T_4[401] : T_4 extends {
            400: any;
        } ? T_4[400] : T_4 extends {
            422: any;
        } ? T_4[422] : T_4 extends {
            418: any;
        } ? T_4[418] : T_4 extends {
            417: any;
        } ? T_4[417] : T_4 extends {
            416: any;
        } ? T_4[416] : T_4 extends {
            415: any;
        } ? T_4[415] : T_4 extends {
            414: any;
        } ? T_4[414] : T_4 extends {
            413: any;
        } ? T_4[413] : T_4 extends {
            412: any;
        } ? T_4[412] : T_4 extends {
            411: any;
        } ? T_4[411] : T_4 extends {
            410: any;
        } ? T_4[410] : T_4 extends {
            409: any;
        } ? T_4[409] : T_4 extends {
            408: any;
        } ? T_4[408] : T_4 extends {
            407: any;
        } ? T_4[407] : T_4 extends {
            406: any;
        } ? T_4[406] : T_4 extends {
            405: any;
        } ? T_4[405] : T_4 extends {
            default: any;
        } ? T_4["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a PUT endpoint */
    put<U_1 extends { [Path_1 in keyof T]: T[Path_1] extends {
        put: unknown;
    } ? Path_1 : never; }[keyof T], M_1 extends keyof T[U_1]>(url: U_1, options: (T[U_1][M_1] extends infer T_5 ? T_5 extends T[U_1][M_1] ? T_5 extends {
        parameters: any;
    } ? {
        params: T_5["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_1][M_1] extends infer T_6 ? T_6 extends T[U_1][M_1] ? T_6 extends {
        parameters: any;
    } ? {
        params: T_6["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_1][M_1] extends infer T_7 ? T_7 extends T[U_1][M_1] ? T_7 extends {
        requestBody: any;
    } ? {
        body: Unwrap<T_7["requestBody"]>;
    } : {
        body?: undefined;
    } : never : never) & Omit<RequestInit, "body">): Promise<{
        data: T[U_1][keyof T[U_1]] extends {
            responses: any;
        } ? Unwrap<T[U_1][keyof T[U_1]]["responses"] extends infer T_8 ? T_8 extends T[U_1][keyof T[U_1]]["responses"] ? T_8 extends {
            200: any;
        } ? T_8[200] : T_8 extends {
            201: any;
        } ? T_8[201] : T_8 extends {
            202: any;
        } ? T_8[202] : T_8 extends {
            default: any;
        } ? T_8["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[U_1][keyof T[U_1]] extends {
            responses: any;
        } ? Unwrap<T[U_1][keyof T[U_1]]["responses"] extends infer T_9 ? T_9 extends T[U_1][keyof T[U_1]]["responses"] ? T_9 extends {
            500: any;
        } ? T_9[500] : T_9 extends {
            404: any;
        } ? T_9[404] : T_9 extends {
            402: any;
        } ? T_9[402] : T_9 extends {
            401: any;
        } ? T_9[401] : T_9 extends {
            400: any;
        } ? T_9[400] : T_9 extends {
            422: any;
        } ? T_9[422] : T_9 extends {
            418: any;
        } ? T_9[418] : T_9 extends {
            417: any;
        } ? T_9[417] : T_9 extends {
            416: any;
        } ? T_9[416] : T_9 extends {
            415: any;
        } ? T_9[415] : T_9 extends {
            414: any;
        } ? T_9[414] : T_9 extends {
            413: any;
        } ? T_9[413] : T_9 extends {
            412: any;
        } ? T_9[412] : T_9 extends {
            411: any;
        } ? T_9[411] : T_9 extends {
            410: any;
        } ? T_9[410] : T_9 extends {
            409: any;
        } ? T_9[409] : T_9 extends {
            408: any;
        } ? T_9[408] : T_9 extends {
            407: any;
        } ? T_9[407] : T_9 extends {
            406: any;
        } ? T_9[406] : T_9 extends {
            405: any;
        } ? T_9[405] : T_9 extends {
            default: any;
        } ? T_9["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a POST endpoint */
    post<U_2 extends { [Path_2 in keyof T]: T[Path_2] extends {
        post: unknown;
    } ? Path_2 : never; }[keyof T], M_2 extends keyof T[U_2]>(url: U_2, options: (T[U_2][M_2] extends infer T_10 ? T_10 extends T[U_2][M_2] ? T_10 extends {
        parameters: any;
    } ? {
        params: T_10["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_2][M_2] extends infer T_11 ? T_11 extends T[U_2][M_2] ? T_11 extends {
        parameters: any;
    } ? {
        params: T_11["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_2][M_2] extends infer T_12 ? T_12 extends T[U_2][M_2] ? T_12 extends {
        requestBody: any;
    } ? {
        body: Unwrap<T_12["requestBody"]>;
    } : {
        body?: undefined;
    } : never : never) & Omit<RequestInit, "body">): Promise<{
        data: T[U_2][keyof T[U_2]] extends {
            responses: any;
        } ? Unwrap<T[U_2][keyof T[U_2]]["responses"] extends infer T_13 ? T_13 extends T[U_2][keyof T[U_2]]["responses"] ? T_13 extends {
            200: any;
        } ? T_13[200] : T_13 extends {
            201: any;
        } ? T_13[201] : T_13 extends {
            202: any;
        } ? T_13[202] : T_13 extends {
            default: any;
        } ? T_13["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[U_2][keyof T[U_2]] extends {
            responses: any;
        } ? Unwrap<T[U_2][keyof T[U_2]]["responses"] extends infer T_14 ? T_14 extends T[U_2][keyof T[U_2]]["responses"] ? T_14 extends {
            500: any;
        } ? T_14[500] : T_14 extends {
            404: any;
        } ? T_14[404] : T_14 extends {
            402: any;
        } ? T_14[402] : T_14 extends {
            401: any;
        } ? T_14[401] : T_14 extends {
            400: any;
        } ? T_14[400] : T_14 extends {
            422: any;
        } ? T_14[422] : T_14 extends {
            418: any;
        } ? T_14[418] : T_14 extends {
            417: any;
        } ? T_14[417] : T_14 extends {
            416: any;
        } ? T_14[416] : T_14 extends {
            415: any;
        } ? T_14[415] : T_14 extends {
            414: any;
        } ? T_14[414] : T_14 extends {
            413: any;
        } ? T_14[413] : T_14 extends {
            412: any;
        } ? T_14[412] : T_14 extends {
            411: any;
        } ? T_14[411] : T_14 extends {
            410: any;
        } ? T_14[410] : T_14 extends {
            409: any;
        } ? T_14[409] : T_14 extends {
            408: any;
        } ? T_14[408] : T_14 extends {
            407: any;
        } ? T_14[407] : T_14 extends {
            406: any;
        } ? T_14[406] : T_14 extends {
            405: any;
        } ? T_14[405] : T_14 extends {
            default: any;
        } ? T_14["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a DELETE endpoint */
    del<U_3 extends { [Path_3 in keyof T]: T[Path_3] extends {
        delete: unknown;
    } ? Path_3 : never; }[keyof T], M_3 extends keyof T[U_3]>(url: U_3, options: (T[U_3][M_3] extends infer T_15 ? T_15 extends T[U_3][M_3] ? T_15 extends {
        parameters: any;
    } ? {
        params: T_15["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_3][M_3] extends infer T_16 ? T_16 extends T[U_3][M_3] ? T_16 extends {
        parameters: any;
    } ? {
        params: T_16["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_3][M_3] extends infer T_17 ? T_17 extends T[U_3][M_3] ? T_17 extends {
        requestBody: any;
    } ? {
        body: Unwrap<T_17["requestBody"]>;
    } : {
        body?: undefined;
    } : never : never) & Omit<RequestInit, "body">): Promise<{
        data: T[U_3][keyof T[U_3]] extends {
            responses: any;
        } ? Unwrap<T[U_3][keyof T[U_3]]["responses"] extends infer T_18 ? T_18 extends T[U_3][keyof T[U_3]]["responses"] ? T_18 extends {
            200: any;
        } ? T_18[200] : T_18 extends {
            201: any;
        } ? T_18[201] : T_18 extends {
            202: any;
        } ? T_18[202] : T_18 extends {
            default: any;
        } ? T_18["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[U_3][keyof T[U_3]] extends {
            responses: any;
        } ? Unwrap<T[U_3][keyof T[U_3]]["responses"] extends infer T_19 ? T_19 extends T[U_3][keyof T[U_3]]["responses"] ? T_19 extends {
            500: any;
        } ? T_19[500] : T_19 extends {
            404: any;
        } ? T_19[404] : T_19 extends {
            402: any;
        } ? T_19[402] : T_19 extends {
            401: any;
        } ? T_19[401] : T_19 extends {
            400: any;
        } ? T_19[400] : T_19 extends {
            422: any;
        } ? T_19[422] : T_19 extends {
            418: any;
        } ? T_19[418] : T_19 extends {
            417: any;
        } ? T_19[417] : T_19 extends {
            416: any;
        } ? T_19[416] : T_19 extends {
            415: any;
        } ? T_19[415] : T_19 extends {
            414: any;
        } ? T_19[414] : T_19 extends {
            413: any;
        } ? T_19[413] : T_19 extends {
            412: any;
        } ? T_19[412] : T_19 extends {
            411: any;
        } ? T_19[411] : T_19 extends {
            410: any;
        } ? T_19[410] : T_19 extends {
            409: any;
        } ? T_19[409] : T_19 extends {
            408: any;
        } ? T_19[408] : T_19 extends {
            407: any;
        } ? T_19[407] : T_19 extends {
            406: any;
        } ? T_19[406] : T_19 extends {
            405: any;
        } ? T_19[405] : T_19 extends {
            default: any;
        } ? T_19["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a OPTIONS endpoint */
    options<U_4 extends { [Path_4 in keyof T]: T[Path_4] extends {
        options: unknown;
    } ? Path_4 : never; }[keyof T], M_4 extends keyof T[U_4]>(url: U_4, options: (T[U_4][M_4] extends infer T_20 ? T_20 extends T[U_4][M_4] ? T_20 extends {
        parameters: any;
    } ? {
        params: T_20["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_4][M_4] extends infer T_21 ? T_21 extends T[U_4][M_4] ? T_21 extends {
        parameters: any;
    } ? {
        params: T_21["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_4][M_4] extends infer T_22 ? T_22 extends T[U_4][M_4] ? T_22 extends {
        requestBody: any;
    } ? {
        body: Unwrap<T_22["requestBody"]>;
    } : {
        body?: undefined;
    } : never : never) & Omit<RequestInit, "body">): Promise<{
        data: T[U_4][keyof T[U_4]] extends {
            responses: any;
        } ? Unwrap<T[U_4][keyof T[U_4]]["responses"] extends infer T_23 ? T_23 extends T[U_4][keyof T[U_4]]["responses"] ? T_23 extends {
            200: any;
        } ? T_23[200] : T_23 extends {
            201: any;
        } ? T_23[201] : T_23 extends {
            202: any;
        } ? T_23[202] : T_23 extends {
            default: any;
        } ? T_23["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[U_4][keyof T[U_4]] extends {
            responses: any;
        } ? Unwrap<T[U_4][keyof T[U_4]]["responses"] extends infer T_24 ? T_24 extends T[U_4][keyof T[U_4]]["responses"] ? T_24 extends {
            500: any;
        } ? T_24[500] : T_24 extends {
            404: any;
        } ? T_24[404] : T_24 extends {
            402: any;
        } ? T_24[402] : T_24 extends {
            401: any;
        } ? T_24[401] : T_24 extends {
            400: any;
        } ? T_24[400] : T_24 extends {
            422: any;
        } ? T_24[422] : T_24 extends {
            418: any;
        } ? T_24[418] : T_24 extends {
            417: any;
        } ? T_24[417] : T_24 extends {
            416: any;
        } ? T_24[416] : T_24 extends {
            415: any;
        } ? T_24[415] : T_24 extends {
            414: any;
        } ? T_24[414] : T_24 extends {
            413: any;
        } ? T_24[413] : T_24 extends {
            412: any;
        } ? T_24[412] : T_24 extends {
            411: any;
        } ? T_24[411] : T_24 extends {
            410: any;
        } ? T_24[410] : T_24 extends {
            409: any;
        } ? T_24[409] : T_24 extends {
            408: any;
        } ? T_24[408] : T_24 extends {
            407: any;
        } ? T_24[407] : T_24 extends {
            406: any;
        } ? T_24[406] : T_24 extends {
            405: any;
        } ? T_24[405] : T_24 extends {
            default: any;
        } ? T_24["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a HEAD endpoint */
    head<U_5 extends { [Path_5 in keyof T]: T[Path_5] extends {
        head: unknown;
    } ? Path_5 : never; }[keyof T], M_5 extends keyof T[U_5]>(url: U_5, options: (T[U_5][M_5] extends infer T_25 ? T_25 extends T[U_5][M_5] ? T_25 extends {
        parameters: any;
    } ? {
        params: T_25["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_5][M_5] extends infer T_26 ? T_26 extends T[U_5][M_5] ? T_26 extends {
        parameters: any;
    } ? {
        params: T_26["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_5][M_5] extends infer T_27 ? T_27 extends T[U_5][M_5] ? T_27 extends {
        requestBody: any;
    } ? {
        body: Unwrap<T_27["requestBody"]>;
    } : {
        body?: undefined;
    } : never : never) & Omit<RequestInit, "body">): Promise<{
        data: T[U_5][keyof T[U_5]] extends {
            responses: any;
        } ? Unwrap<T[U_5][keyof T[U_5]]["responses"] extends infer T_28 ? T_28 extends T[U_5][keyof T[U_5]]["responses"] ? T_28 extends {
            200: any;
        } ? T_28[200] : T_28 extends {
            201: any;
        } ? T_28[201] : T_28 extends {
            202: any;
        } ? T_28[202] : T_28 extends {
            default: any;
        } ? T_28["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[U_5][keyof T[U_5]] extends {
            responses: any;
        } ? Unwrap<T[U_5][keyof T[U_5]]["responses"] extends infer T_29 ? T_29 extends T[U_5][keyof T[U_5]]["responses"] ? T_29 extends {
            500: any;
        } ? T_29[500] : T_29 extends {
            404: any;
        } ? T_29[404] : T_29 extends {
            402: any;
        } ? T_29[402] : T_29 extends {
            401: any;
        } ? T_29[401] : T_29 extends {
            400: any;
        } ? T_29[400] : T_29 extends {
            422: any;
        } ? T_29[422] : T_29 extends {
            418: any;
        } ? T_29[418] : T_29 extends {
            417: any;
        } ? T_29[417] : T_29 extends {
            416: any;
        } ? T_29[416] : T_29 extends {
            415: any;
        } ? T_29[415] : T_29 extends {
            414: any;
        } ? T_29[414] : T_29 extends {
            413: any;
        } ? T_29[413] : T_29 extends {
            412: any;
        } ? T_29[412] : T_29 extends {
            411: any;
        } ? T_29[411] : T_29 extends {
            410: any;
        } ? T_29[410] : T_29 extends {
            409: any;
        } ? T_29[409] : T_29 extends {
            408: any;
        } ? T_29[408] : T_29 extends {
            407: any;
        } ? T_29[407] : T_29 extends {
            406: any;
        } ? T_29[406] : T_29 extends {
            405: any;
        } ? T_29[405] : T_29 extends {
            default: any;
        } ? T_29["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a PATCH endpoint */
    patch<U_6 extends { [Path_6 in keyof T]: T[Path_6] extends {
        patch: unknown;
    } ? Path_6 : never; }[keyof T], M_6 extends keyof T[U_6]>(url: U_6, options: (T[U_6][M_6] extends infer T_30 ? T_30 extends T[U_6][M_6] ? T_30 extends {
        parameters: any;
    } ? {
        params: T_30["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_6][M_6] extends infer T_31 ? T_31 extends T[U_6][M_6] ? T_31 extends {
        parameters: any;
    } ? {
        params: T_31["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_6][M_6] extends infer T_32 ? T_32 extends T[U_6][M_6] ? T_32 extends {
        requestBody: any;
    } ? {
        body: Unwrap<T_32["requestBody"]>;
    } : {
        body?: undefined;
    } : never : never) & Omit<RequestInit, "body">): Promise<{
        data: T[U_6][keyof T[U_6]] extends {
            responses: any;
        } ? Unwrap<T[U_6][keyof T[U_6]]["responses"] extends infer T_33 ? T_33 extends T[U_6][keyof T[U_6]]["responses"] ? T_33 extends {
            200: any;
        } ? T_33[200] : T_33 extends {
            201: any;
        } ? T_33[201] : T_33 extends {
            202: any;
        } ? T_33[202] : T_33 extends {
            default: any;
        } ? T_33["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[U_6][keyof T[U_6]] extends {
            responses: any;
        } ? Unwrap<T[U_6][keyof T[U_6]]["responses"] extends infer T_34 ? T_34 extends T[U_6][keyof T[U_6]]["responses"] ? T_34 extends {
            500: any;
        } ? T_34[500] : T_34 extends {
            404: any;
        } ? T_34[404] : T_34 extends {
            402: any;
        } ? T_34[402] : T_34 extends {
            401: any;
        } ? T_34[401] : T_34 extends {
            400: any;
        } ? T_34[400] : T_34 extends {
            422: any;
        } ? T_34[422] : T_34 extends {
            418: any;
        } ? T_34[418] : T_34 extends {
            417: any;
        } ? T_34[417] : T_34 extends {
            416: any;
        } ? T_34[416] : T_34 extends {
            415: any;
        } ? T_34[415] : T_34 extends {
            414: any;
        } ? T_34[414] : T_34 extends {
            413: any;
        } ? T_34[413] : T_34 extends {
            412: any;
        } ? T_34[412] : T_34 extends {
            411: any;
        } ? T_34[411] : T_34 extends {
            410: any;
        } ? T_34[410] : T_34 extends {
            409: any;
        } ? T_34[409] : T_34 extends {
            408: any;
        } ? T_34[408] : T_34 extends {
            407: any;
        } ? T_34[407] : T_34 extends {
            406: any;
        } ? T_34[406] : T_34 extends {
            405: any;
        } ? T_34[405] : T_34 extends {
            default: any;
        } ? T_34["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a TRACE endpoint */
    trace<U_7 extends { [Path_7 in keyof T]: T[Path_7] extends {
        trace: unknown;
    } ? Path_7 : never; }[keyof T], M_7 extends keyof T[U_7]>(url: U_7, options: (T[U_7][M_7] extends infer T_35 ? T_35 extends T[U_7][M_7] ? T_35 extends {
        parameters: any;
    } ? {
        params: T_35["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_7][M_7] extends infer T_36 ? T_36 extends T[U_7][M_7] ? T_36 extends {
        parameters: any;
    } ? {
        params: T_36["parameters"];
    } : {
        params?: BaseParams | undefined;
    } : never : never) & (T[U_7][M_7] extends infer T_37 ? T_37 extends T[U_7][M_7] ? T_37 extends {
        requestBody: any;
    } ? {
        body: Unwrap<T_37["requestBody"]>;
    } : {
        body?: undefined;
    } : never : never) & Omit<RequestInit, "body">): Promise<{
        data: T[U_7][keyof T[U_7]] extends {
            responses: any;
        } ? Unwrap<T[U_7][keyof T[U_7]]["responses"] extends infer T_38 ? T_38 extends T[U_7][keyof T[U_7]]["responses"] ? T_38 extends {
            200: any;
        } ? T_38[200] : T_38 extends {
            201: any;
        } ? T_38[201] : T_38 extends {
            202: any;
        } ? T_38[202] : T_38 extends {
            default: any;
        } ? T_38["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[U_7][keyof T[U_7]] extends {
            responses: any;
        } ? Unwrap<T[U_7][keyof T[U_7]]["responses"] extends infer T_39 ? T_39 extends T[U_7][keyof T[U_7]]["responses"] ? T_39 extends {
            500: any;
        } ? T_39[500] : T_39 extends {
            404: any;
        } ? T_39[404] : T_39 extends {
            402: any;
        } ? T_39[402] : T_39 extends {
            401: any;
        } ? T_39[401] : T_39 extends {
            400: any;
        } ? T_39[400] : T_39 extends {
            422: any;
        } ? T_39[422] : T_39 extends {
            418: any;
        } ? T_39[418] : T_39 extends {
            417: any;
        } ? T_39[417] : T_39 extends {
            416: any;
        } ? T_39[416] : T_39 extends {
            415: any;
        } ? T_39[415] : T_39 extends {
            414: any;
        } ? T_39[414] : T_39 extends {
            413: any;
        } ? T_39[413] : T_39 extends {
            412: any;
        } ? T_39[412] : T_39 extends {
            411: any;
        } ? T_39[411] : T_39 extends {
            410: any;
        } ? T_39[410] : T_39 extends {
            409: any;
        } ? T_39[409] : T_39 extends {
            408: any;
        } ? T_39[408] : T_39 extends {
            407: any;
        } ? T_39[407] : T_39 extends {
            406: any;
        } ? T_39[406] : T_39 extends {
            405: any;
        } ? T_39[405] : T_39 extends {
            default: any;
        } ? T_39["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
};
export {};
